.. _trojanzoo.utils.model:

model
======

.. currentmodule:: trojanzoo.utils.model

.. autofunction:: init_weights
.. autofunction:: get_layer_name
.. autofunction:: get_all_layer
.. autofunction:: get_layer
.. autofunction:: summary
.. autofunction:: activate_params
.. autofunction:: accuracy
.. autofunction:: generate_target
.. autoclass:: ExponentialMovingAverage
